//******************************************************************************
// SCICHART® Copyright SciChart Ltd. 2011-2019. All rights reserved.
//
// Web: http://www.scichart.com
// Support: support@scichart.com
// Sales:   sales@scichart.com
//
// SCIPieChartSurface.h is part of SCICHART®, High Performance Scientific Charts
// For full terms and conditions of the license, see http://www.scichart.com/scichart-eula/
//
// This source code is protected by international copyright law. Unauthorized
// reproduction, reverse-engineering, or distribution of all or any portion of
// this source code is strictly prohibited.
//
// This source code contains confidential and proprietary trade secrets of
// SciChart Ltd., and should at no time be copied, transferred, sold,
// distributed or made available without express written permission.
//******************************************************************************

#import "SCILayoutableView.h"
#import "ISCIPieChartSurface.h"
#import "ISCIPropertyHolder.h"
#import "ISCIInvalidatableElement.h"

NS_ASSUME_NONNULL_BEGIN

/**
 * Provides a chart surface which contains a single `SCIPieChartRenderSurface` viewport
 * for rendering multiple `ISCIPieRenderableSeries` and where each `ISCIPieRenderableSeries` may have
 * a `ISCIPieSegment` in the appropriate `SCIPieSegmentCollection` as a source.
 * <p>
 * The `SCIPieChartSurface` may have zero or many `ISCIPieChartModifier` to enable interaction with the chart.
 * @see ISCIPieChartSurface
 * @see ISCIPieSegment
 * @see ISCIPieRenderableSeries
 * @see ISCIPieChartModifier
 * @see SCIPieRenderableSeries
 * @see SCIDonutRenderableSeries
 */
@interface SCIPieChartSurface : SCILayoutableView<ISCIPieChartSurface, ISCIPropertyHolder, ISCIInvalidatableElement>

/**
 * Defines the current theme applied to this `SCIChartSurfaceBase`.
 */
@property (nonatomic) NSString *themeId;

/**
 * Defines the collection of ISCIPieRenderableSeries that this `SCIPieChartSurface` draws.
 * @see SCIPieRenderableSeriesCollection
 */
@property (nonatomic) SCIPieRenderableSeriesCollection *renderableSeries;

/**
 * Defines the collection of `ISCIPieChartModifier` that this `SCIPieChartSurface` uses
 */
@property (nonatomic) SCIPieChartModifierCollection *chartModifiers;

@end

NS_ASSUME_NONNULL_END
